@@ -598,10 +598,13 @@ int Preferences::ExplorerShell()
         ".asf;ASFFile\r\n"
         ".at3;ATRACFile\r\n"
         ".au;AUFile\r\n"
+        ".aud;AUDFile\r\n"
+        ".aue;AUEFile\r\n"
         ".avi;AVIFile\r\n"
         ".bdmv;BDMVFile\r\n"
         ".bmp;BMPFile\r\n"
         ".bms;BMPFile\r\n"
+        ".braw;BRAWFile\r\n"
         ".caf;CAFFile\r\n"
         ".clpi;CLPIFile\r\n"
         ".dde;DolbyEFile\r\n"
@@ -610,6 +613,7 @@ int Preferences::ExplorerShell()
         ".dff;DFFFile\r\n"
         ".dsf;DSFFile\r\n"
         ".dts;DTSFile\r\n"
+        ".dtshd;DTSFile\r\n"
         ".dv;EAC3File\r\n"
         ".dvr;DVRFile\r\n"
         ".dvr-ms;DVRMSFile\r\n"
@@ -1220,9 +1224,12 @@ int Preferences::ShellToolTip()
         ".amr;AMRFile\r\n"
         ".ape;APEFile\r\n"
         ".asf;ASFFile\r\n"
+        ".aud;AUDFile\r\n"
+        ".aue;AUEFile\r\n"
         ".avi;AVIFile\r\n"
         ".bdmv;BDMVFile\r\n"
         ".bmp;BMPFile\r\n"
+        ".braw;BRAWFile\r\n"
         ".clpi;CLPIFile\r\n"
         ".dde;DolbyEFile\r\n"
         ".divx;AVIFile\r\n"
@@ -1230,6 +1237,7 @@ int Preferences::ShellToolTip()
         ".dsf;DFFFile\r\n"
         ".dsf;DSFFile\r\n"
         ".dts;DTSFile\r\n"
+        ".dtshd;DTSFile\r\n"
         ".dv;EAC3File\r\n"
         ".dvr;DVRFile\r\n"
         ".dvr-ms;DVRMSFile\r\n"
