@@ -16,13 +16,14 @@
 #define kTreeTabIndex 1
 #define kTextTabIndex 2
 #define kCompareTabIndex 3
+#define kHTMLTabIndex 4
 
 #define kApplicationMenuTag 10
 #define kSubscribeMenuItemTag 11
 #define kViewMenuTag 50
+#define kOptionsMenuTag 53
 #define kCompareMenuItemTag 51
 #define kAdvancedMenuItemTag 52
-#define kAdvancedMenuItemSeparatorTag 53
 
 NSString* TextKindToNSString(ViewMenu_Kind kind)
 {
@@ -33,7 +34,10 @@ NSString* TextKindToNSString(ViewMenu_Kind kind)
 		case Kind_XML:			_ret = @"XML"; break;
 		case Kind_CSV:			_ret = @"CSV"; break;
 		case Kind_JSON:			_ret = @"JSON"; break;
-		case Kind_MPEG7:		_ret = @"MPEG-7"; break;
+		case Kind_Graph_Svg:		_ret = @"Graph_Svg"; break;
+		case Kind_MPEG7_Strict:		_ret = @"MPEG-7_Strict"; break;
+		case Kind_MPEG7_Relaxed:	_ret = @"MPEG-7_Relaxed"; break;
+		case Kind_MPEG7_Extended:	_ret = @"MPEG-7_Extended"; break;
 		case Kind_PBCore:		_ret = @"PBCore"; break;
 		case Kind_PBCore2:		_ret = @"PBCore2"; break;
 		case Kind_EBUCore_1_5:	_ret = @"EBUCore_1.5"; break;
@@ -92,12 +96,20 @@ NSString* TextKindToNSString(ViewMenu_Kind kind)
                 [self selectCompareTab:nil];
             else if ([defaultView isEqualToString:@"Text"])
                 [self selectTextTab:nil];
+            else if ([defaultView isEqualToString:@"HTML"])
+                [self selectViewHTML:nil];
             else if ([defaultView isEqualToString:@"XML"])
                 [self selectViewXML:nil];
             else if ([defaultView isEqualToString:@"JSON"])
                 [self selectViewJSON:nil];
-            else if ([defaultView isEqualToString:@"MPEG-7"])
-                [self selectViewMPEG7:nil];
+            else if ([defaultView isEqualToString:@"Graph_Svg"])
+                [self selectViewGraph_Svg:nil];
+            else if ([defaultView isEqualToString:@"MPEG-7_Strict"])
+                [self selectViewMPEG7_Strict:nil];
+            else if ([defaultView isEqualToString:@"MPEG-7_Relaxed"])
+                [self selectViewMPEG7_Relaxed:nil];
+            else if ([defaultView isEqualToString:@"MPEG-7_Extended"])
+                [self selectViewMPEG7_Extended:nil];
             else if ([defaultView isEqualToString:@"PBCore"])
                 [self selectViewPBCore:nil];
             else if ([defaultView isEqualToString:@"PBCore2"])
@@ -155,7 +167,9 @@ NSString* TextKindToNSString(ViewMenu_Kind kind)
 	NSOpenPanel *openPanel	= [NSOpenPanel openPanel];
 	[openPanel setCanChooseDirectories:YES];
 	[openPanel setAllowsMultipleSelection:YES];
-	[openPanel setCanDownloadUbiquitousContents:NO];
+    if (@available(macOS 10.10, *)) {
+	    [openPanel setCanDownloadUbiquitousContents:NO];
+    }
 	[openPanel beginSheetModalForWindow:[self window] completionHandler:^(NSInteger result){
 		if(result == NSFileHandlingPanelOKButton) {
 			[self processFiles:[openPanel URLs]];
@@ -246,8 +260,33 @@ NSString* TextKindToNSString(ViewMenu_Kind kind)
     [self showFileSelector];
 	_lastTextKind = _kind;
 	[tabSelector setSelectedSegment:tabSelector.segmentCount - 1];
-	[self updateTextTabWithFileAtIndex:selectedFileIndex];
-	[tabs selectTabViewItemAtIndex:kTextTabIndex];
+    if (_kind==Kind_HTML || _kind==Kind_Graph_Svg)
+    {
+        if ([[NSUserDefaults standardUserDefaults] objectForKey:@"graphAdmShowTrackUIDs"]!=nil)
+        {
+            BOOL value = [[NSUserDefaults standardUserDefaults] boolForKey:@"graphAdmShowTrackUIDs"];
+            [oMediaInfoList setOptionStatic:@"Graph_Adm_ShowTrackUIDs" withValue:(value?@"1":@"0")];
+        }
+
+        if ([[NSUserDefaults standardUserDefaults] objectForKey:@"graphAdmShowChannelFormat"]!=nil)
+        {
+            BOOL value = [[NSUserDefaults standardUserDefaults] boolForKey:@"graphAdmShowChannelFormats"];
+            [oMediaInfoList setOptionStatic:@"Graph_Adm_ShowChannelFormats" withValue:(value?@"1":@"0")];
+        }
+
+        [self updateHTMLTabWithFileAtIndex:selectedFileIndex];
+        [tabs selectTabViewItemAtIndex:kHTMLTabIndex];
+    }
+    else
+    {
+        [self updateTextTabWithFileAtIndex:selectedFileIndex];
+        [tabs selectTabViewItemAtIndex:kTextTabIndex];
+    }
+}
+
+-(IBAction)selectViewHTML:(id)sender
+{
+    [self _selectViewOFKind:Kind_HTML];
 }
 
 -(IBAction)selectViewXML:(id)sender
@@ -260,9 +299,19 @@ NSString* TextKindToNSString(ViewMenu_Kind kind)
 	[self _selectViewOFKind:Kind_JSON];
 }
 
--(IBAction)selectViewMPEG7:(id)sender
+-(IBAction)selectViewMPEG7_Strict:(id)sender
 {
-	[self _selectViewOFKind:Kind_MPEG7];
+	[self _selectViewOFKind:Kind_MPEG7_Strict];
+}
+
+-(IBAction)selectViewMPEG7_Relaxed:(id)sender
+{
+	[self _selectViewOFKind:Kind_MPEG7_Relaxed];
+}
+
+-(IBAction)selectViewMPEG7_Extended:(id)sender
+{
+	[self _selectViewOFKind:Kind_MPEG7_Extended];
 }
 
 -(IBAction)selectViewPBCore:(id)sender
@@ -330,6 +379,11 @@ NSString* TextKindToNSString(ViewMenu_Kind kind)
 	[self _selectViewOFKind:Kind_NISO_Z39_87];
 }
 
+-(IBAction)selectViewGraph_Svg:(id)sender
+{
+	[self _selectViewOFKind:Kind_Graph_Svg];
+}
+
 
 - (NSDragOperation)draggingEntered:(id <NSDraggingInfo>)sender {
 	
@@ -370,8 +424,10 @@ NSString* TextKindToNSString(ViewMenu_Kind kind)
 
 	NSInteger tag = exportFormatButton.selectedTag;
 
-	if (tag == 4 || tag == 12 || tag == 13)
+	if (tag == 4 || tag == 15 || tag == 16)
 		[_exportSavePanel setAllowedFileTypes:@[@"json"]];
+	else if (tag == 5)
+		[_exportSavePanel setAllowedFileTypes:@[@"svg"]];
 	else if (tag == 3)
 		[_exportSavePanel setAllowedFileTypes:@[@"csv"]];
 	else if (tag == 1)
@@ -420,45 +476,54 @@ NSString* TextKindToNSString(ViewMenu_Kind kind)
 					format = TextKindToNSString(Kind_JSON);
 					break;
 				case 5:
-					format = TextKindToNSString(Kind_MPEG7);
+					format = TextKindToNSString(Kind_Graph_Svg);
 					break;
 				case 6:
-					format = TextKindToNSString(Kind_PBCore);
+					format = TextKindToNSString(Kind_MPEG7_Strict);
 					break;
 				case 7:
-					format = TextKindToNSString(Kind_PBCore2);
+					format = TextKindToNSString(Kind_MPEG7_Relaxed);
 					break;
 				case 8:
-					format = TextKindToNSString(Kind_EBUCore_1_5);
+					format = TextKindToNSString(Kind_MPEG7_Extended);
 					break;
 				case 9:
-					format = TextKindToNSString(Kind_EBUCore_1_6);
+					format = TextKindToNSString(Kind_PBCore);
 					break;
 				case 10:
-					format = TextKindToNSString(Kind_EBUCore_1_8_ps);
+					format = TextKindToNSString(Kind_PBCore2);
 					break;
 				case 11:
-					format = TextKindToNSString(Kind_EBUCore_1_8_sp);
+					format = TextKindToNSString(Kind_EBUCore_1_5);
 					break;
 				case 12:
-					format = TextKindToNSString(Kind_EBUCore_1_8_ps_json);
+					format = TextKindToNSString(Kind_EBUCore_1_6);
 					break;
 				case 13:
-					format = TextKindToNSString(Kind_EBUCore_1_8_sp_json);
+					format = TextKindToNSString(Kind_EBUCore_1_8_ps);
 					break;
 				case 14:
-					format = TextKindToNSString(Kind_FIMS_1_1);
+					format = TextKindToNSString(Kind_EBUCore_1_8_sp);
 					break;
 				case 15:
-					format = TextKindToNSString(Kind_FIMS_1_2);
+					format = TextKindToNSString(Kind_EBUCore_1_8_ps_json);
 					break;
 				case 16:
-					format = TextKindToNSString(Kind_FIMS_1_3);
+					format = TextKindToNSString(Kind_EBUCore_1_8_sp_json);
 					break;
 				case 17:
-					format = TextKindToNSString(Kind_reVTMD);
+					format = TextKindToNSString(Kind_FIMS_1_1);
 					break;
 				case 18:
+					format = TextKindToNSString(Kind_FIMS_1_2);
+					break;
+				case 19:
+					format = TextKindToNSString(Kind_FIMS_1_3);
+					break;
+				case 20:
+					format = TextKindToNSString(Kind_reVTMD);
+					break;
+				case 21:
 					format = TextKindToNSString(Kind_NISO_Z39_87);
 					break;
 				case 0:
@@ -505,12 +570,12 @@ NSString* TextKindToNSString(ViewMenu_Kind kind)
         if(view && view.submenu) {
             NSMenuItem *compare = [view.submenu itemWithTag:kCompareMenuItemTag];
             [compare setHidden:NO];
+        }
 
-            NSMenuItem *advanced = [view.submenu itemWithTag:kAdvancedMenuItemTag];
+        NSMenuItem *options = [menu itemWithTag:kOptionsMenuTag];
+        if(options && options.submenu) {
+            NSMenuItem *advanced = [options.submenu itemWithTag:kAdvancedMenuItemTag];
             [advanced setHidden:NO];
-
-            NSMenuItem *separator = [view.submenu itemWithTag:kAdvancedMenuItemSeparatorTag];
-            [separator setHidden:NO];
         }
     }
 
@@ -628,6 +693,9 @@ NSString* TextKindToNSString(ViewMenu_Kind kind)
 	//Text View
 	[self updateTextTabWithFileAtIndex:index];
 
+    //HTML View
+    [self updateHTMLTabWithFileAtIndex:index];
+
 	//tree view
 	[treeView setIndex:index];
 
@@ -717,6 +785,28 @@ NSString* TextKindToNSString(ViewMenu_Kind kind)
 
 }
 
+-(void)updateHTMLTabWithFileAtIndex:(NSUInteger)index
+{
+    if (_lastTextKind!=Kind_HTML && _lastTextKind!=Kind_Graph_Svg)
+        return;
+
+    NSString *_inform = TextKindToNSString(_lastTextKind);
+    [mediaList setOption:@"Inform" withValue:_inform];
+
+    NSString *html=[mediaList informAtIndex:index];
+    if (_lastTextKind==Kind_Graph_Svg)
+    {
+        NSRange range = [html rangeOfString:@"<svg"];
+        if (range.length)
+            html=[html substringFromIndex:range.location];
+        
+        NSString *path = [[NSBundle mainBundle] pathForResource:@"/Plugin/Graph/Template" ofType:@"html"];
+        NSString *template = [NSString stringWithContentsOfFile:path encoding:NSUTF8StringEncoding error:NULL];
+        html=[template stringByReplacingOccurrencesOfString:@"@SVG@" withString:html];
+    }
+    [htmlField setContent:html];
+    [mediaList setOption:@"Inform" withValue:@""];
+}
 
 -(void)updateTextTabWithFileAtIndex:(NSUInteger)index
 {
@@ -897,6 +987,10 @@ NSString* TextKindToNSString(ViewMenu_Kind kind)
     else if(action == @selector(selectCompareTab:)) {
 		[menuItem setState: ([tabs indexOfTabViewItem:tabs.selectedTabViewItem] == kCompareTabIndex ? NSOnState : NSOffState)];
 	}
+    else if(action == @selector(selectViewHTML:)) {
+        BOOL state = [tabs indexOfTabViewItem:tabs.selectedTabViewItem] == kHTMLTabIndex && _lastTextKind == Kind_HTML ? YES : NO;
+        [menuItem setState: (state ? NSOnState : NSOffState)];
+    }
 	else if(action == @selector(selectViewXML:)) {
 		BOOL state = [tabs indexOfTabViewItem:tabs.selectedTabViewItem] == kTextTabIndex && _lastTextKind == Kind_XML ? YES : NO;
 		[menuItem setState: (state ? NSOnState : NSOffState)];
@@ -905,8 +999,20 @@ NSString* TextKindToNSString(ViewMenu_Kind kind)
 		BOOL state = [tabs indexOfTabViewItem:tabs.selectedTabViewItem] == kTextTabIndex && _lastTextKind == Kind_JSON ? YES : NO;
 		[menuItem setState: (state ? NSOnState : NSOffState)];
 	}
-	else if(action == @selector(selectViewMPEG7:)) {
-		BOOL state = [tabs indexOfTabViewItem:tabs.selectedTabViewItem] == kTextTabIndex && _lastTextKind == Kind_MPEG7 ? YES : NO;
+	else if(action == @selector(selectViewGraph_Svg:)) {
+		BOOL state = [tabs indexOfTabViewItem:tabs.selectedTabViewItem] == kTextTabIndex && _lastTextKind == Kind_Graph_Svg ? YES : NO;
+		[menuItem setState: (state ? NSOnState : NSOffState)];
+	}
+	else if(action == @selector(selectViewMPEG7_Strict:)) {
+		BOOL state = [tabs indexOfTabViewItem:tabs.selectedTabViewItem] == kTextTabIndex && _lastTextKind == Kind_MPEG7_Strict ? YES : NO;
+		[menuItem setState: (state ? NSOnState : NSOffState)];
+	}
+	else if(action == @selector(selectViewMPEG7_Relaxed:)) {
+		BOOL state = [tabs indexOfTabViewItem:tabs.selectedTabViewItem] == kTextTabIndex && _lastTextKind == Kind_MPEG7_Relaxed ? YES : NO;
+		[menuItem setState: (state ? NSOnState : NSOffState)];
+	}
+	else if(action == @selector(selectViewMPEG7_Extended:)) {
+		BOOL state = [tabs indexOfTabViewItem:tabs.selectedTabViewItem] == kTextTabIndex && _lastTextKind == Kind_MPEG7_Extended ? YES : NO;
 		[menuItem setState: (state ? NSOnState : NSOffState)];
 	}
 	else if(action == @selector(selectViewPBCore:)) {
@@ -1022,8 +1128,8 @@ NSString* TextKindToNSString(ViewMenu_Kind kind)
     if(mediaList && [mediaList count]) {
 
         if ([tabs indexOfTabViewItem:tabs.selectedTabViewItem] == kCompareTabIndex) {
-            if(compareView.selectedIndex > 0 && (compareView.selectedIndex - 1) < [mediaList count])
-                [self closeFileAtIndex:(compareView.selectedIndex - 1)];
+            if(compareView.selectedIndex >= 0 && (compareView.selectedIndex) < [mediaList count])
+                [self closeFileAtIndex:(compareView.selectedIndex)];
 
             return;
         }
@@ -1077,4 +1183,20 @@ NSString* TextKindToNSString(ViewMenu_Kind kind)
         }
     }
 }
+
+-(IBAction)fullParse:(id)sender {
+    if([sender isKindOfClass: [NSMenuItem class]]) {
+        NSMenuItem* item = sender;
+
+        BOOL newState = !item.state;
+        [item setState:newState];
+
+        [oMediaInfoList setOptionStatic:@"ParseSpeed" withValue:(newState?@"1":@"0.5")];
+
+        if(mediaList && selectedFileIndex < [mediaList count]) {
+            [self showFileAtIndex:selectedFileIndex];
+        }
+    }
+}
+
 @end
