@@ -48,7 +48,7 @@ using namespace ZenLib;
 #define QString2wstring(_DATA) \
     Ztring().From_UTF8(_DATA.toUtf8())
 
-#define VERSION "22.12"
+#define VERSION "23.04"
 #if defined(_WIN32) && defined(WINAPI_FAMILY) && (WINAPI_FAMILY==WINAPI_FAMILY_APP) //UWP Application
 #include <QtPlatformHeaders/QWindowsWindowFunctions>
 #include <ZenLib/Os_Utils.h>
@@ -614,13 +614,30 @@ void MainWindow::refreshDisplay() {
                 xis->setContent(wstring2QString(C->Inform_Get()));
                 ((QTextBrowser*)viewWidget)->setText(xis->toString(4));
                 break;
-            case VIEW_MPEG7:
-                C->Menu_View_MPEG7();
+            case VIEW_MPEG7_Strict:
+                C->Menu_View_MPEG7_Strict();
                 viewWidget = new QTextBrowser();
                 xis = new QDomDocument();
                 xis->setContent(wstring2QString(C->Inform_Get()));
                 ((QTextBrowser*)viewWidget)->setText(xis->toString(4));
                 break;
+
+            case VIEW_MPEG7_Relaxed:
+                C->Menu_View_MPEG7_Relaxed();
+                viewWidget = new QTextBrowser();
+                xis = new QDomDocument();
+                xis->setContent(wstring2QString(C->Inform_Get()));
+                ((QTextBrowser*)viewWidget)->setText(xis->toString(4));
+                break;
+
+            case VIEW_MPEG7_Extended:
+                C->Menu_View_MPEG7_Extended();
+                viewWidget = new QTextBrowser();
+                xis = new QDomDocument();
+                xis->setContent(wstring2QString(C->Inform_Get()));
+                ((QTextBrowser*)viewWidget)->setText(xis->toString(4));
+                break;
+
             case VIEW_XML:
                 C->Menu_View_XML();
                 viewWidget = new QTextBrowser();
@@ -997,7 +1014,7 @@ void MainWindow::on_actionOpen_Folder_triggered()
 
 void MainWindow::on_actionAbout_triggered()
 {
-    About a(VERSION, this);
+    About a(this);
     a.exec();
 }
 
@@ -1144,8 +1161,16 @@ void MainWindow::on_actionExport_triggered()
             C->Menu_View_NISO_Z39_87();
             file.write(wstring2QString(C->Inform_Get()).toStdString().c_str());
             break;
-        case Export::MPEG7:
-            C->Menu_View_MPEG7();
+        case Export::MPEG7_Strict:
+            C->Menu_View_MPEG7_Strict();
+            file.write(wstring2QString(C->Inform_Get()).toStdString().c_str());
+            break;
+        case Export::MPEG7_Relaxed:
+            C->Menu_View_MPEG7_Relaxed();
+            file.write(wstring2QString(C->Inform_Get()).toStdString().c_str());
+            break;
+        case Export::MPEG7_Extended:
+            C->Menu_View_MPEG7_Extended();
             file.write(wstring2QString(C->Inform_Get()).toStdString().c_str());
             break;
         default:
@@ -1163,6 +1188,12 @@ void MainWindow::on_actionAdvanced_Mode_toggled(bool checked)
     refreshDisplay();
 }
 
+void MainWindow::on_actionFull_Parse_toggled(bool checked)
+{
+    C->MI->Option_Static(__T("ParseSpeed"), checked?__T("1"):__T("0.5"));
+    refreshDisplay();
+}
+
 void MainWindow::on_actionClose_All_triggered()
 {
     C->Menu_File_Open_Files_Begin(true);
