@@ -127,6 +127,8 @@ __published:    // IDE-managed Components
     TMenuItem *N5;
     TMenuItem *M_Options_CloseAllAuto;
     TMenuItem *M_Options_Z1;
+    TMenuItem *M_Options_FullParsing;
+    TMenuItem *M_Options_Z2;
     TMenuItem *M_Options_Preferences;
     TMenuItem *M_Debug;
     TMenuItem *M_Debug_Header;
@@ -181,7 +183,9 @@ __published:    // IDE-managed Components
     TMenuItem *M_NewVersion;
     TMenuItem *M_View_XML;
     TMenuItem *M_View_JSON;
-    TMenuItem *M_View_MPEG7;
+    TMenuItem *M_View_MPEG7_Strict;
+    TMenuItem *M_View_MPEG7_Relaxed;
+    TMenuItem *M_View_MPEG7_Extended;
     TMenuItem *M_View_PBCore;
     TMenuItem *M_View_PBCore2;
     TMenuItem *M_View_EBUCore_1_5;
@@ -199,7 +203,9 @@ __published:    // IDE-managed Components
     TMenuItem *M_View_Graph_Svg;
     TMenuItem *ToolBar_View_XML;
     TMenuItem *ToolBar_View_JSON;
-    TMenuItem *ToolBar_View_MPEG7;
+    TMenuItem *ToolBar_View_MPEG7_Strict;
+    TMenuItem *ToolBar_View_MPEG7_Relaxed;
+    TMenuItem *ToolBar_View_MPEG7_Extended;
     TMenuItem *ToolBar_View_PBCore;
     TMenuItem *ToolBar_View_PBCore2;
     TMenuItem *ToolBar_View_EBUCore_1_5;
@@ -214,7 +220,6 @@ __published:    // IDE-managed Components
     TMenuItem *ToolBar_View_reVTMD;
     TMenuItem *ToolBar_View_NISO_Z39_87;
     TMenuItem *ToolBar_View_Graph_Svg;
-    TMenuItem *M_Debug_FullParsing;
     void __fastcall FormResize(TObject *Sender);
     void __fastcall M_Help_AboutClick(TObject *Sender);
     void __fastcall M_Options_PreferencesClick(TObject *Sender);
@@ -268,7 +273,9 @@ __published:    // IDE-managed Components
     void __fastcall Donate_zh_TWClick(TObject *Sender);
     void __fastcall Donate___Click(TObject *Sender);
     void __fastcall M_NewVersionClick(TObject *Sender);
-    void __fastcall M_View_MPEG7Click(TObject *Sender);
+    void __fastcall M_View_MPEG7_StrictClick(TObject *Sender);
+    void __fastcall M_View_MPEG7_RelaxedClick(TObject *Sender);
+    void __fastcall M_View_MPEG7_ExtendedClick(TObject *Sender);
     void __fastcall M_View_PBCoreClick(TObject *Sender);
     void __fastcall M_View_PBCore2Click(TObject *Sender);
     void __fastcall M_View_EBUCore_1_5Click(TObject *Sender);
@@ -286,7 +293,7 @@ __published:    // IDE-managed Components
     void __fastcall M_View_reVTMDClick(TObject *Sender);
     void __fastcall M_View_NISO_Z39_87Click(TObject *Sender);
     void __fastcall M_View_Graph_SvgClick(TObject *Sender);
-    void __fastcall M_Debug_FullParsingClick(TObject *Sender);
+    void __fastcall M_Options_FullParsingClick(TObject *Sender);
 private:    // User declarations
 public:        // User declarations
     MESSAGE void __fastcall HandleDropFiles (TMessage&);
